﻿using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Threading.Tasks;
using System.Xml.Linq;

namespace AVBFeedReader.Models
{
    public class DataManager
    {
        public static DataManager Instance = new DataManager();

        private DataManager()
        {
        }

        public async Task<IEnumerable<FeedItem>> UpdateFeed(string url)
        {
            string result = string.Empty;
            HttpWebRequest request = WebRequest.CreateHttp(url);
            request.Accept = "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8";

            request.Headers[HttpRequestHeader.AcceptEncoding] = "gzip";
            WebResponse response = await request.GetResponseAsync();

            using (Stream stream = response.GetResponseStream())
            {
                using (var reader = new StreamReader(stream))
                {
                    result = await reader.ReadToEndAsync();
                }
            }
            XElement feed = XElement.Parse(result);

            IEnumerable<FeedItem> articles = from item in feed.Descendants("item")
                select new FeedItem
                {
                    Title = item.Element("title").Value,
                    PublishDate = item.Element("pubDate").Value,
                    Description = item.Element("description").Value,
                    ArticleUrl = item.Element("link").Value
                };
            return articles;
        }
    }
}