﻿using System;
using System.Windows.Input;

namespace AVBFeedReader.Utilities
{
    public class DelegateCommand : ICommand
    {
        private readonly Func<object, bool> _canExecute;
        private readonly Action<object> _executeAction;

        public DelegateCommand(Action<object> executeAction,
            Func<object, bool> canExecute = null)
        {
            if (executeAction == null)
            {
                throw new
                    ArgumentNullException("executeAction");
            }
            _executeAction = executeAction;
            _canExecute = canExecute;
        }

        public bool CanExecute(object parameter)
        {
            bool result = true;
            if (_canExecute != null)
            {
                result = _canExecute(parameter);
                RaiseCanExecuteChanged();
            }
            return result;
        }

        public event EventHandler CanExecuteChanged;

        public void Execute(object parameter)
        {
            _executeAction(parameter);
        }

        public void RaiseCanExecuteChanged()
        {
            if (CanExecuteChanged != null)
            {
                CanExecuteChanged(this,
                                  new EventArgs());
            }
        }
    }
}