﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using Windows.ApplicationModel;
using AVBFeedReader.Models;
using AVBFeedReader.Utilities;

namespace AVBFeedReader.ViewModels
{
    public class FeedReaderViewModel : ViewModelBase
    {
        private ObservableCollection<FeedItem> _feedItems;

        public FeedReaderViewModel()
        {
            if (DesignMode.DesignModeEnabled)
            {
                FeedItems = new ObservableCollection<FeedItem>
                {
                    new FeedItem
                    {
                        ArticleUrl = "http://demo.server.de/some/path/someId.html",
                        PublishDate = DateTime.Now.ToString("f"),
                        Title = "Design Entry 01",
                        Description =
                            "Das ist ein Design Dateneintrag für die Visualisierung im UI Designer oder Blend."
                    },
                    new FeedItem
                    {
                        ArticleUrl = "http://demo.server.de/some/path/someId.html",
                        PublishDate = DateTime.Now.ToString("f"),
                        Title = "Design Entry 02",
                        Description = "Das ist ein noch ein Design Dateneintrag, mit einer anderem Beschreibung."
                    },
                };
            }
            else
            {
                RefreshCommand = new DelegateCommand(async arg =>
                {
                    IEnumerable<FeedItem> res = await DataManager.Instance.UpdateFeed("http://gordon-breuer.de/feed/");
                    FeedItems = new ObservableCollection<FeedItem>(res);
                });
            }
        }

        public ObservableCollection<FeedItem> FeedItems
        {
            get { return _feedItems; }
            private set
            {
                if (_feedItems == value)
                {
                    return;
                }
                _feedItems = value;
                OnPropertyChanged();
            }
        }

        public DelegateCommand RefreshCommand { get; private set; }
    }
}